@@ -5,15 +5,19 @@
 # TODO: figure out something to make dia windows always big enough, yet fit nicely in the terminal
 
 
-# you should call this function when you want to use this library (can be called multiple times, to change ui type or other settings)
-# $1 ui type (dia or cli). defaults to cli
-# $2 directory for tmp files. default /tmp (leave empty for default)
-# $3 logfile (or string of logfiles, separated by whitespace) (leave empty to disable logging)
-# $4 debug categories (leave empty to disable debugging) (an array of categories you will use in debug calls. useful when grepping logfiles)
+# you can call this function to change settings, before calling other libui functions or afterwards
+# it must always be called at least once to set the right variables, but it gets automatically called once at the end of this file
+# Don't set the variable or leave it empty to set the default value
+# $1 ui type (dia or cli). default: cli
+# $2 directory for tmp files. default: /tmp
+# $3 logfile (or string of logfiles, separated by whitespace). default: no logging
+# $4 array of categories you will use in debug calls. (useful when grepping logfiles). default: no debugging
 # this library uses the UI debug category internally, you don't need to specify it. we add it automatically
-libui-sh-init ()
+libui_sh_init ()
 {
 	LIBUI_UI=${1:-cli}
+	allowed_uis=('cli' 'dia')
+	check_is_in "$LIBUI_UI" "${allowed_uis[@]}" || die_error "libui_sh_init \$1 must be one of 'cli', 'dia' or '' (for cli)"
 	[ "$LIBUI_UI" == 'dialog' ] && ! which dialog &>/dev/null && die_error "Required dependency dialog not found"
 	LIBUI_TMP_DIR=/tmp
 	if [ -n "$2" ]; then
@@ -729,3 +733,7 @@ _cli_follow_progress ()
 	[ -n "$3" ] && tail -f $2 --pid=$3
 	[ -z "$3" ] && tail -f $2
 }
+
+
+libui_sh_init
+
